@@ -79,7 +79,7 @@ def print_info(log_str):
         m.data = log_str
         m.status = True
         m.error = 0
-        all_publisher.publish(m.__str__())
+        all_publisher.publish(m.get_json())
         if isPrintInfo:
             print(log_str)
     except Exception as ex:
@@ -95,7 +95,7 @@ def print_debug(log_str):
         m.data = log_str
         m.status = True
         m.error = 0
-        debug_publisher.publish(m.__str__())
+        debug_publisher.publish(m.get_json())
         if isPrintDebug:
             print(log_str)
     except Exception as ex:
@@ -111,7 +111,7 @@ def print_error(log_str):
         m.data = log_str
         m.status = True
         m.error = 0
-        error_publisher.publish(m.__str__())
+        error_publisher.publish(m.get_json())
         if isPrintError:
             print(log_str)
     except Exception as ex:
